const axios = require('axios');
const config = require('../config');

const self = axios.create({
    baseURL: `http://0.0.0.0:${config.PORT}`,
    timeout: 1000
});
const authMock = {
    key: config.APPSERVICES_KEY,
    orgid: 1,
    environment: 'diagnosis',
    loginid: 1,
    orgrole: 'ALL_AND_CSR',
    user: {
        loginId: 1,
        currentOrgId: 1,
        requestRole: 'r',
        orgRoles: {
            1: 'ALL_AND_CSR'
        }
    }
};

const diagnose = async (ctx, next) => {
    const health = {};
    try {
        if (!ctx.request.query.key || ctx.request.query.key !== config.DIAGNOSTIC_KEY) {
            throw new Error('Please provide a valid diagnostic key.');
        }

        const status = await self.get('/status');
        health.status = status.status;

        const authorize = await self.post('/authorize', authMock);
        health.authorize = authorize.status;

        if (!authorize.data || !authorize.data.access_token) {
            throw new Error('Expect /authorize to return an access_token!');
        }

        try {
            const notifications = await self.get('/notifications', { headers: { Authorization: `Bearer ${authorize.data.access_token}` } });
            health.get_notifications = notifications.status;
        } catch (err) {
            throw new Error(`Expected /notifications to return 200. Error: ${err.message}`);
        }

        ctx.status = 200;
        ctx.body = { status: 'OK', health };
    } catch (err) {
        ctx.status = 500;
        ctx.body = { status: 'ERROR', error: err.message, request_response: err.response && err.response.data, health };
    }
    return next();
};

module.exports = {
    '/diagnose': {
        get: {
            description: 'Runs a full diagnostic of the service.',
            run: diagnose
        }
    }
};
