const os = require('os');
const config = require('../config');
const db = require('../utils/db');

const status = async (ctx, next) => {
    try {
        ctx.status = 200;
        // Hash is required by validation CI/CD step
        ctx.body = { server: os.hostname(), version: config.VERSION, hash: config.HASH };
    } catch (err) {
        ctx.status = 500;
        ctx.body = { error: err.message };
    }
    return next();
};

const dbstatus = async (ctx, next) => {
    try {
        await db.authenticate();
        ctx.status = 200;
        ctx.body = { server: os.hostname(), version: config.VERSION, dbstatus: 'authenticated' };
    } catch (err) {
        ctx.status = 500;
        ctx.body = { error: err.message };
    }
    return next();
};

module.exports = {
    '/health_check': {
        get: {
            description: 'Check if the service is running.',
            run: status
        }
    },
    '/db_health_check': {
        get: {
            description: 'Check if the service is running and DB is functional.',
            run: dbstatus
        }
    },
};
