const NotificationHistory = require('../models/notificationHistory');
const config = require('../config');

const get = async (ctx, next) => {
    ctx.assert(ctx.state.user, 403, 'User not logged in!');
    ctx.assert(await ctx.state.checkPermission('org.alerts', 'READ'), 403, 'User not allowed to read notifications.');
    ctx.assert(config.ENABLE_NOTIFICATION_HISTORY, 404, 'History not enabled');
    ctx.assert(ctx.query.rule_id || ctx.query.alert_id, 400, 'You must specify a rule ID or alert ID.');

    try {
        ctx.status = 200;

        const where = {
            orgid: ctx.state.user.orgid
        };
        if (ctx.query.alert_id) {
            where.incident_id = ctx.query.alert_id;
        }
        if (ctx.query.rule_id) {
            where.alert_rule_id = ctx.query.rule_id;
        }
        const limit = Math.min(Math.abs(parseFloat(ctx.query.limit) || 50), 200);
        const offset = Math.abs(limit * (parseFloat(ctx.query.page || 1) - 1) || 0);

        const notifications = await NotificationHistory.findAll({
            where,
            attributes: NotificationHistory.fields.filter(field => field.exposed).map(f => f.name),
            order: [
                ['createdat', 'DESC']
            ],
            limit,
            offset
        });

        if (ctx.state.auditLog && config.ENABLE_VERBOSE_AUDIT) {
            ctx.state.auditLog(`User retrieved notifications history for ${JSON.stringify(where)}.`);
        }
        ctx.body.items = notifications.map(notification => notification.get({ plain: true }));
    } catch (err) {
        ctx.status = 500;
        ctx.body.error = err.message;
    }
    return next();
};


module.exports = {
    '/history': {
        get: {
            description: 'Returns a history of notifications that were sent out.',
            run: get
        }
    },
};
