const router = require('koa-router')();
const config = require('../config');
const notifications = require('./notifications');
const settings = require('./settings');
const health = require('./health');
const history = require('./history');
const diagnose = require('./diagnose');
const stats = require('./stats');
const shutdown = require('./shutdown');
const mergeDeep = require('../utils/mergeDeep');
const responses = require('../utils/responses');

const routes = mergeDeep(
    health,
    notifications,
    history,
    settings,
    stats,
    diagnose,
    shutdown
);
const basePath = `/${config.SERVICE_NAME}/${config.VERSION}`;
router.prefix(basePath);
const swagger = {};

const mount = (app) => {
    Object.keys(routes).forEach((resource) => {
        Object.keys(routes[resource]).forEach((method) => {
            if (!routes[resource][method] || !routes[resource][method].run) {
                throw new Error(`Incomplete resource definition ${resource}:${method}`);
            }
            swagger[resource] = swagger[resource] || {};
            swagger[resource][method] = mergeDeep(
                {
                    description: `${method} ${resource}`,
                    consumes: ['application/json'],
                    produces: ['application/json'],
                    responses
                },
                routes[resource][method]
            );
            delete swagger[resource][method].run;
            router[method](resource, routes[resource][method].run);
        });
    });
    router.get('/swagger', async (ctx, next) => {
        ctx.status = 200;
        ctx.body = {
            basePath,
            schemes: ['http', 'https'],
            swagger: '2.0',
            info: {
                title: config.SERVICE_LABEL,
                version: config.VERSION
            },
            paths: swagger
        };
        return next();
    });
    app.use(router.routes());
    app.use(router.allowedMethods());
};

module.exports = mount;
