const Users = require('../models/users');
const config = require('../config');

const get = async (ctx, next) => {
    ctx.assert(ctx.state.user, 403, `User not logged in! ${JSON.stringify(ctx.state)}`);
    const user = ctx.state.user.get({ plain: true });
    if (ctx.state.auditLog && config.ENABLE_VERBOSE_AUDIT) {
        ctx.state.auditLog('User retrieved their notification settings.');
    }
    ctx.status = 200;
    user.subscriptions = user.subscriptions || Users.defaultSubscriptions;
    ctx.body = user;
    return next();
};

const patch = async (ctx, next) => {
    ctx.assert(ctx.state.user, 403, `User not logged in! ${JSON.stringify(ctx.state)}`);
    try {
        const where = { id: ctx.state.user.id };
        const attributes = Users.fields.filter(f => f.exposed).map(f => f.name);
        const user = await Users.findOne({ where, attributes });
        if (!user) {
            throw new Error('User no longer exists!');
        }
        const update = Object.keys(ctx.request.body)
            .filter(key => Users.fields.filter(f => f.editable).map(f => f.name).includes(key))
            .reduce((obj, key) => {
                const field = Users.fields.find(f => f.name === key);
                obj[key] = (
                    field.beforeSave ?
                        field.beforeSave(ctx.request.body[key], user[key]) :
                        ctx.request.body[key]
                );
                return obj;
            }, {});
        user.update(update);
        await user.save();

        if (ctx.state.auditLog) {
            ctx.state.auditLog('User updated their notification settings.');
        }
        ctx.status = 200;
        ctx.body = user;
    } catch (err) {
        ctx.status = 400;
        ctx.body.error = err.message;
    }
    return next();
};


module.exports = {
    '/settings': {
        get: {
            description: 'Retrieves user\'s settings',
            run: get
        },
        patch: {
            description: 'Updates user\'s settings',
            run: patch
        }
    }
};
