const yn = require('yn');

if (!process.env.POSTGRES_URI && !process.env.POSTGRES_HOST) {
    throw new Error('POSTGRES_HOST not defined!');
}
if (!process.env.POSTGRES_URI && !process.env.POSTGRES_USER) {
    throw new Error('POSTGRES_USER not defined!');
}
if (!process.env.POSTGRES_URI && !process.env.PGPASSWORD) {
    throw new Error('PGPASSWORD not defined!');
}
if (!process.env.POSTGRES_URI && !process.env.POSTGRES_DB_NAME) {
    throw new Error('POSTGRES_DB_NAME not defined!');
}

module.exports = {
    SERVICE_NAME: process.env.SERVICE_NAME || 'notification',
    SERVICE_LABEL: process.env.SERVICE_LABEL || 'Cb Notification Service',
    VERSION: 'v1',
    HOST: process.env.HOST || '0.0.0.0',
    PORT: process.env.PORT || 8012,
    HASH: process.env.HASH || 'missing!',
    AWS_DEFAULT_REGION: process.env.AWS_DEFAULT_REGION,
    // Method for sending emails ('ses' for IAM auth'd SES, 'smtp' for static SMTP creds, or 'test' for dummy creds)
    EMAIL_SENDING_MODE: process.env.EMAIL_SENDING_MODE || 'test',
    EMAIL_SENDING_REGION: process.env.AWS_SES_REGION || 'us-east-1',
    EMAIL_SENDER_USER: process.env.EMAIL_SENDER_USER,
    EMAIL_SENDER_PASSWORD: process.env.EMAIL_SENDER_PASSWORD,
    EMAIL_SHOW_LOGS: yn(process.env.EMAIL_SHOW_LOGS, {default: true}),
    DEBUG: yn(process.env.DEBUG, {default: false}),
    POSTGRES_URI: process.env.POSTGRES_URI || `postgres://${process.env.POSTGRES_USER}:${process.env.PGPASSWORD}@${process.env.POSTGRES_HOST || 'postgres'}:${process.env.POSTGRES_PORT || '5432'}/${process.env.POSTGRES_DB_NAME || 'localdev'}`,
    ES_ENDPOINT: process.env.ES_ENDPOINT,
    // list of environments separated by ","
    ACTIVE_ENVIRONMENTS: process.env.ACTIVE_ENVIRONMENTS,
    // Temporary workaround: use passwords for endpoints.
    APPSERVICES_KEY: process.env.APPSERVICES_KEY || 'setamoresecurekeyhereplz!',
    DIAGNOSTIC_KEY: process.env.DIAGNOSTIC_KEY || 'onlyforopstesters',
    STATS_KEY: process.env.STATS_KEY || 'setamoresecurekeyhereplz!',
    TIMEZONE: process.env.TIMEZONE || 'UTC',
    FROM_EMAIL: process.env.FROM_EMAIL,
    // validity in seconds
    TOKEN_VALIDITY_LENGTH: process.env.TOKEN_VALIDITY_LENGTH || 3900,
    // ages in days
    MAX_NOTIFICATION_HISTORY_AGE: parseInt(process.env.MAX_NOTIFICATION_HISTORY_AGE, 10) || 180,
    MAX_NOTIFICATIONS_AGE: parseInt(process.env.MAX_READ_NOTIFICATIONS_AGE, 10) || 180,
    MAX_READ_NOTIFICATIONS_AGE: parseInt(process.env.MAX_READ_NOTIFICATIONS_AGE, 10) || 30,
    // number of queue consumers for each environment
    MAX_QUEUE_WORKERS: parseInt(process.env.MAX_QUEUE_WORKERS, 10) || 5,
    // 1-10
    QUEUE_BATCH_SIZE: parseInt(process.env.QUEUE_BATCH_SIZE, 10) || 10,
    MAX_EMAILS_PER_DAY: 0,
    // max size of notification creation chunk size, default to 20000
    // 10000 users consume approx. 350 mb memory so tune this size accordingly
    MAX_NOTIFICATION_CREATION_CHUNK_SIZE: parseInt(process.env.MAX_NOTIFICATION_CREATION_CHUNK_SIZE, 10) || 20000,
    // Feature flags
    ENABLE_EMAIL_SUPPORT: yn(process.env.ENABLE_EMAIL_SUPPORT, {default: true}),
    EMAIL_FLOOD_FILTER_ENABLED: yn(process.env.EMAIL_FLOOD_FILTER_ENABLED, {default: false}),
    EMAIL_FLOOD_FILTER_ORG_KEY_LIST: process.env.EMAIL_FLOOD_FILTER_ORG_KEY_LIST || "",
    ENABLE_NOTIFICATION_HISTORY: yn(process.env.ENABLE_NOTIFICATION_HISTORY, {default: false}),
    ENABLE_RATE_LIMITING: yn(process.env.ENABLE_RATE_LIMITING, {default: false}),
    ENABLE_VERBOSE_AUDIT: yn(process.env.VERBOSE_AUDIT, {default: false}),

    // Local development SQS endpoint URL
    LOCALDEV_SQS_ENDPOINT: process.env.LOCALDEV_SQS_ENDPOINT || 'https://mockaws:4576',

    // Flags to enable different aspects of the notification service
    ENABLE_API: yn(process.env.ENABLE_API, {default: false}),
    ENABLE_QUEUE_PROCESSOR: yn(process.env.ENABLE_QUEUE_PROCESSOR, {default: false}),
    ENABLE_CLEANUP: yn(process.env.ENABLE_CLEANUP, {default: false}),
    // whether to use SSL to connect to database
    SECURE_CONNECTION_TO_DB: yn(process.env.SECURE_CONNECTION_TO_DB, {default: false}),
    // whether service is running in a gov environment
    GOV: yn(process.env.GOV, {default: false}),
    // when it is single environment and single queue deployment, set queue name
    SQS_QUEUE_NAME: process.env.SQS_QUEUE_NAME,
    SQS_QUEUE_URL: process.env.SQS_QUEUE_URL,
    // Base URL for static assets referenced in emails
    DASHBOARD_URL: process.env.DASHBOARD_URL,
    GATEWAY_URL: process.env.GATEWAY_URL,
    GATEWAY_FORWARD_HOST: process.env.GATEWAY_FORWARD_HOST,
    NOTIFICATION_RULE_SERVICE_CONNECTOR_SECRET_KEY: process.env.NOTIFICATION_RULE_SERVICE_CONNECTOR_SECRET_KEY,
    INTERNAL_INGRESS_HOST_NAME: process.env.INTERNAL_INGRESS_HOST_NAME,
};
