const Koa = require('koa');
const config = require('./config');
const mount = require('./api/mount');
const middleware = require('./utils/middleware');
const queueConsumer = require('./jobs/queueConsumer');
const cleanup = require('./jobs/cleanup');

if (config.ENABLE_API) {
    console.log('API Enabled');

    const app = new Koa();
    app.use(middleware);
    mount(app);

    app.listen(
        config.PORT,
        config.HOST,
        () => console.log(`listening http://${config.HOST}:${config.PORT}/${config.SERVICE_NAME}/${config.VERSION}`)
    );
}

if (config.ENABLE_QUEUE_PROCESSOR) {
    console.log('Queue Processor Enabled');
    queueConsumer.start();
}

if (config.ENABLE_CLEANUP) {
    console.log('Cleanup Enabled');
    cleanup.start();
}

if (!config.ENABLE_API && !config.ENABLE_QUEUE_PROCESSOR && !config.ENABLE_CLEANUP) {
    console.error('No components enabled! Exiting...');
}