const sequelize = require('sequelize');
const Notifications = require('../models/notifications');
const NotificationHistory = require('../models/notificationHistory');
const config = require('../config');

const ONE_DAY = 86400000;
const service = {};

service.run = async () => {
    try {
        // Delete only entries that have been marked as read and older than set days
        const readMaxAge = ONE_DAY * config.MAX_READ_NOTIFICATIONS_AGE;
        const readNotifications = await Notifications.destroy({
            where: {
                readtime: {
                    [sequelize.Op.ne]: null
                },
                createdat: {
                    [sequelize.Op.lt]: new Date(Date.now() - readMaxAge)
                }
            }
        });
        console.log(`${(new Date()).toLocaleString()} Deleted ${readNotifications} notifications older than ${config.MAX_READ_NOTIFICATIONS_AGE} days that were read.`);

        // Delete entries that are older than max age
        const allMaxAge = ONE_DAY * config.MAX_NOTIFICATIONS_AGE;
        const oldNotifications = await Notifications.destroy({
            where: {
                createdat: {
                    [sequelize.Op.lt]: new Date((new Date()).getTime() - allMaxAge)
                }
            }
        });
        console.log(`${(new Date()).toLocaleString()} Deleted ${oldNotifications} notifications older than ${config.MAX_NOTIFICATIONS_AGE} days.`);

        // Delete old notification history
        const historyMaxAge = ONE_DAY * config.MAX_NOTIFICATION_HISTORY_AGE;
        const oldNotificationsHistory = await NotificationHistory.destroy({
            where: {
                createdat: {
                    [sequelize.Op.lt]: new Date(Date.now() - historyMaxAge)
                }
            }
        });
        console.log(`${(new Date()).toLocaleString()} Deleted ${oldNotificationsHistory} notifications history older than ${config.MAX_NOTIFICATION_HISTORY_AGE} days.`);
    } catch (error) {
        console.error(error.message);
        throw new Error(error.message);
    }
};
service.start = (interval = 3600000) => {
    service.run();
    service._interval = setInterval(() => service.run(), interval);
};
service.stop = () => {
    if (service._interval) {
        clearInterval(service._interval);
    }
};

module.exports = service;
