const axios = require('axios');

const NOTIFICATIONS_TOKEN = process.env.NOTIFICATIONS_TOKEN;
if (!NOTIFICATIONS_TOKEN) {
    throw new Error('No NOTIFICATIONS_TOKEN provided.');
}
const NOTIFICATIONS_API = process.env.NOTIFICATIONS_API;
if (!NOTIFICATIONS_API) {
    throw new Error('No NOTIFICATIONS_API provided.');
}
const APPSERVICES_KEY = process.env.APPSERVICES_KEY;
if (!APPSERVICES_KEY) {
    throw new Error('No APPSERVICES_KEY provided.');
}
const orgIds = {
    prod01: [428],
    prod02: [1510],
    prod03: [],
    prod04: [],
    prod05: [4144],
    prod06: [1390]
};
const api = axios.create({
    baseURL: NOTIFICATIONS_API,
    timeout: 30000,
    headers: {
        Authorization: `Bearer ${NOTIFICATIONS_TOKEN}`
    }
});

const send = async () => {
    try {
        // const authorization = {
        //     key: APPSERVICES_KEY,
        //     environment: 'environment',
        //     user: {
        //         loginId: 1,
        //         currentOrgId: 1,
        //         orgrole: {
        //             1: 'ALL_AND_CSR'
        //         }
        //     },
        //     requestRole: 'w'
        // };
        let totalNotifications = 0;
        // const auth = await api.post('/authorize', authorization);
        const environments = Object.keys(orgIds);
        await Promise.all(environments.map(async (environment) => {
            console.log(`[${environment}] ${orgIds[environment].length} orgs to process.`);
            for (let i = 0; i < orgIds[environment].length; i++) {
                const notification = {
                    type: 'announcement',
                    title: 'Windows Sensor 3.2 Issues',
                    content: 'There are confirmed issues with the automatic updates of signatures in the Windows 3.2.0.213 sensor. We have temporarily removed this version from the UI and recommend using the 3.1 sensor. For more information please see the UEX post.',
                    action: {
                        label: 'Learn More',
                        url: 'https://community.carbonblack.com/community/resources/cb-defense/blog/2018/06/29/cb-defense-32-windows-sensor-signature-pack-update-issue'
                    },
                    where: {
                        environment,
                        orgid: orgIds[environment][i]
                    }
                };
                try {
                    const res = await api.post('/notifications', notification);
                    totalNotifications += res.data.count;
                    console.log(`[${environment}:${orgIds[environment][i]}] Notification posted! ${res.data.count} users were notified`);
                } catch (err) {
                    console.error(`Failed to post notification: ${err.message}`);
                }
            }
        }));
        console.log(`Job done, ${totalNotifications} notifications were sent out.`);
    } catch (err) {
        console.error(`An error occured: ${err.message}`);
    }
};

send();
