const Sequelize = require('sequelize');
const { toSchema, baseFields } = require('../utils/model');

const defaultSubscriptions = {
    // Settings can be extended but must always
    // contain each field value
    announcement: {
        enabled: true,
        delivery: ['in_app']
    },
    threat_score: {
        enabled: true,
        delivery: ['in_app']
    },
    ttp: {
        enabled: true,
        delivery: ['in_app']
    },
    policy_action: {
        enabled: true,
        delivery: ['in_app']
    },
    watchlist: {
        enabled: true,
        delivery: ['in_app']
    },
    getting_started: {
        enabled: true,
        delivery: ['in_app']
    },
    maintenance_no_downtime: {
        enabled: true,
        delivery: ['in_app', 'email_if_unread'],
        config: {
            unreadWindow: 4320000 // 12h
        }
    }
};
const overideSubscriptions = {
    // These will override whatever the user sets.
    support_alert: {
        enabled: true,
        delivery: ['in_app']
    },
    threat_score: {
        enabled: true,
        delivery: ['in_app']
    },
    ttp: {
        enabled: true,
        delivery: ['in_app']
    },
    policy_action: {
        enabled: true,
        delivery: ['in_app']
    },
    watchlist: {
        enabled: true,
        delivery: ['in_app']
    },
    degraded_performance: {
        enabled: true,
        delivery: ['in_app']
    },
    degraded_performance_resolved: {
        enabled: true,
        delivery: ['in_app']
    },
    maintenance: {
        enabled: true,
        delivery: ['in_app']
    },
    export_download: {
        enabled: true,
        delivery: ['in_app']
    },
    job_success: {
        enabled: true,
        delivery: ['in_app']
    },
    job_failed: {
        enabled: true,
        delivery: ['in_app']
    },
};
const fields = baseFields.concat([
    {
        name: 'id',
        type: Sequelize.UUID,
        defaultValue: Sequelize.UUIDV1,
        primaryKey: true,
        exposed: true,
    },
    {
        name: 'orgid',
        type: Sequelize.INTEGER,
        exposed: true,
    },
    {
        name: 'orgkey',
        type: Sequelize.TEXT,
        exposed: true,
    },
    {
        name: 'loginid',
        type: Sequelize.INTEGER,
        exposed: true,
    },
    {
        name: 'environment',
        type: Sequelize.TEXT,
        exposed: true,
    },
    {
        name: 'user_role',
        type: Sequelize.TEXT,
        exposed: true
    },
    {
        /**
         * JSON
         * { type: {
         *   (types)
         *     - announcement
         *     - maintenance
         *     - getting_started
         *     - {ttp_rule}
         *     - {alert}
         *     - ...
         *
         *   enabled: BOOL,
         *   delivery: LIST
         *     default ['in_app', 'email_if_unread']
         *     - in_app
         *     - email
         *     - email_if_unread
         * } }
         */
        name: 'subscriptions',
        type: Sequelize.JSONB,
        exposed: true,
        beforeSave: (value, oldValue) => Object.assign({}, defaultSubscriptions, oldValue, value),
        editable: true
    },
    {
        name: 'config',
        defaultValue: {
            unread_delay: 600000, // if unread for 10min, send to second delivery method.
        },
        type: Sequelize.JSONB,
        exposed: true,
        editable: true
    },
    {
        name: 'persona',
        // security | it | ...
        type: Sequelize.TEXT,
        exposed: true,
        editable: true
    }
]);

const Users = toSchema({
    collection: 'users',
    fields
});

Users.defaultSubscriptions = defaultSubscriptions;
Users.overideSubscriptions = overideSubscriptions;

module.exports = Users;
