const AWS = require('aws-sdk');
const https = require('https');
const base64 = require('base-64');
const config = require('../config');
const sampleNotification = require('./sample_notification');

console.log('Initialize sending test notifications to ', config.LOCALDEV_SQS_ENDPOINT);

AWS.config.update({
    region: config.AWS_DEFAULT_REGION,
    endpoint: config.LOCALDEV_SQS_ENDPOINT,
    httpOptions: { agent: new https.Agent({ rejectUnauthorized: false }) }
});

const queueUrl = `${config.LOCALDEV_SQS_ENDPOINT}/queue/localdev_notification_queue`;
const region = 'us-east-1';

const sendMessage = sqs => (body, QueueUrl) => new Promise((resolve, reject) => {
    sqs.sendMessage({
        MessageBody: base64.encode(JSON.stringify(body)),
        QueueUrl
    }, (err) => {
        if (err) {
            reject(err);
        } else {
            resolve();
        }
    });
});

const run = async () => {
    const sqs = new AWS.SQS({ apiVersion: '2012-11-05', region });

    await sendMessage(sqs)(sampleNotification, queueUrl);

    console.log('sampleNotification inserted!');
    setTimeout(run, 2000);
};

run();
