const axios = require('axios');
const AWS = require('aws-sdk');
const config = require('../config');
const https = require("https");

const environments = config.ACTIVE_ENVIRONMENTS.split(',');
const ssm = environments.includes('localdev') ? new AWS.SSM({
    region: config.AWS_DEFAULT_REGION,
    endpoint: config.LOCALDEV_SSM_ENDPOINT,
    httpOptions: {agent: new https.Agent({rejectUnauthorized: false})}
}) : new AWS.SSM({region: config.AWS_DEFAULT_REGION});
const authTokenPerEnv = {};

const getApiKey = async (gateway) => {
    if (process.env.CONNECTOR_SECRET_KEY) {
        return process.env.CONNECTOR_SECRET_KEY;
    }

    const SSMParam = await ssm.getParameter({
        Name: `/${gateway.origin_env}/notifications/api_token`, WithDecryption: true
    }).promise();

    return (SSMParam && SSMParam.Parameter && SSMParam.Value);
};

const saveAuditLog = async (action, gateway, gateway_user, headers, gatewayUrl, shouldForwardHostHeader) => {

    let host = `${gateway.gateway_public_url.match(/^https/i) ? '' : 'https://'}${gateway.gateway_public_url}`;
    const endpoint = `/appservices/v5/orgs/${gateway_user.target_org.org_key}/auditlog`;
    let url = `${host}${endpoint}`;
    let customHeaders = {};
    try {
        if (!authTokenPerEnv[gateway.origin_env]) {
            console.log(`Retrieving api access token for ${gateway.origin_env}`);
            authTokenPerEnv[gateway.origin_env] = await getApiKey(gateway);
        }
        // authTokenPerEnv[gateway.origin_env] = "test"

        if (authTokenPerEnv[gateway.origin_env]) {
            customHeaders['X-Auth-Token'] = authTokenPerEnv[gateway.origin_env]
            // add the gateway url for the mosaic 2 environment
            if (gatewayUrl) {
                if (config.DEBUG) {
                    console.log(`Gateway Url ${gatewayUrl}`);
                    console.log(`Gateway Public Url ${gateway.gateway_public_url}`);
                    console.log(`shouldForwardHostHeader ${shouldForwardHostHeader}`);
                }
                host = gatewayUrl;
                if (shouldForwardHostHeader) {
                    if (gateway.gateway_public_url.match(/^https/i)) {
                        const url = new URL(gateway.gateway_public_url);
                        customHeaders['Host'] = url.hostname;
                    } else {
                        customHeaders['Host'] = gateway.gateway_public_url;
                    }

                }
                url = `${host}${endpoint}`;
            }
            if (config.DEBUG) {
                console.log(`saveAuditLog Url: ${url}`);
                console.log(`saveAuditLog action: ${JSON.stringify(action)}`);
                console.log(`saveAuditLog Header: ${JSON.stringify(customHeaders)}`);
            }

            await axios.post(url, action, {
                headers: customHeaders
            });
            if (config.DEBUG) {
                console.log("saveAuditLog success")
            }
            return true;

        }
    } catch (err) {
        if (config.DEBUG) {
            console.log(`Failed to store audit log! JSON ${JSON.stringify(err)} gateway public url  ${gateway.gateway_public_url} header ${JSON.stringify(customHeaders)} action ${JSON.stringify(action)}`);
        } else {
            console.log(`Failed to store audit log! ${url} ${err.message} ${err.response && err.response.data}, Host Header ${customHeaders['Host']}`);
        }
        return false;
    }

};

module.exports = saveAuditLog;
