const axios = require('axios');
const config = require('../config');

if(config.DEBUG) {
    axios.interceptors.request.use(x => {
        console.log(x);
        return x;
    })

    axios.interceptors.response.use(x => {
        console.log(x)
        return x;
    })
}

const checkPermission = async (permission, action, gateway, user, headers) => {
    if (!gateway || !user || !action || !permission) {
        console.warn(`Tried to check permission, but some parameters were missing:${gateway ? gateway.gateway_ip : 'no_gateway'}:${user ? user.target_org : 'no_user'}:${permission || 'no_permission'}:${action || 'no_action'}`);

        return false;
    }
    try {
        if (config.DEBUG) {
            console.log(`checkPermission: ${gateway.gateway_ip}:${gateway.gateway_port}:${permission}:${action.toUpperCase()}`);
        }

        await axios.post(
            `http://${gateway.gateway_ip}:${gateway.gateway_port}/access/v1/demand`,
            {
                permissions: [
                    { name: permission, actions: [action.toUpperCase()] }
                ],
                entities: { org: user.target_org.org_key },
                caller: user.target_org
            },
            {
                // access service only requires following three headers to check permissions
                headers: {
                    'Content-Type': 'application/json',
                    'X-User-Context': headers['x-user-context'],
                    'X-Request-Context': headers['x-request-context']
                },
                timeout: 5000
            }
        );

        return true;
    } catch (err) {
        if (err.response) {
            console.log('Failed with', err.response.data);
        }
        console.log(`Failed to check permissions! ${err.message}`);
        return false;
    }
};

module.exports = checkPermission;
