const Sequelize = require('sequelize');
const config = require('../config');

if (!config.POSTGRES_URI) {
    throw new Error('POSTGRES_URI not defined!');
}

let sequelize;
if (config.SECURE_CONNECTION_TO_DB) {
    // use SSL to connect to database
    sequelize = new Sequelize(
        config.POSTGRES_URI,
        {
            define: {
                createdAt: 'createdat',
                updatedAt: 'updatedat'
            },
            dialectOptions: {
                useUTC: true,
                ssl: {
                    required: true,
                    rejectUnauthorized: false
                }
            },
            pool: {
                max: 10,
                acquire: 120000
            },
            timezone: config.TIMEZONE,
            logging: config.DEBUG && console.log
        }
    );
} else {
    // turn SSL off
    sequelize = new Sequelize(
        config.POSTGRES_URI,
        {
            define: {
                createdAt: 'createdat',
                updatedAt: 'updatedat'
            },
            dialectOptions: {
                useUTC: true,
            },
            pool: {
                acquire: 120000
            },
            timezone: config.TIMEZONE,
            logging: config.DEBUG && console.log
        }
    );
}

sequelize.stop = () => {
    sequelize.close().then(() => {
        console.log("Sequelize is closed");
    }).catch((error) => {
        console.error('Failed to close Sequelize', error.message);
    });
};

module.exports = sequelize;
