const config = require("../../config");
const aws = require("aws-sdk");
const nodemailer = require("nodemailer");

const initTransport = () => {
    const knownTransports = {
        test: makeTransportTest,
        smtp: makeTransportSMTP,
        ses: makeTransportSES,
    }

    if (config.EMAIL_SENDING_MODE in knownTransports) {
        return knownTransports[config.EMAIL_SENDING_MODE]();
    }

    throw new Error(`EMAIL_SENDING_MODE value ${config.EMAIL_SENDING_MODE} invalid. Expected one of ${Object.keys(knownTransports)}.`)
}

// Init a nodemailer transport client using IAM-based SES
// Uses the service's IAM credentials/role
const makeTransportSES = () => {
    if (!config.EMAIL_SENDING_REGION) {
        throw new Error('EMAIL_SENDING_REGION not defined!');
    }

    const ses = new aws.SES({apiVersion: '2010-12-01', region: config.EMAIL_SENDING_REGION})

    return nodemailer.createTransport({
        SES: { ses, aws },
    });
}

// Init a nodemailer transport client using static SMTP credentials
// Does not use the service's IAM credentials
// Requires EMAIL_SENDER_USER and EMAIL_SENDER_PASSWORD env vars
const makeTransportSMTP = () => {
    if (!config.EMAIL_SENDER_USER) {
        throw new Error('EMAIL_SENDER_USER not defined!');
    }

    if (!config.EMAIL_SENDER_PASSWORD) {
        throw new Error('EMAIL_SENDER_PASSWORD not defined!');
    }

    return nodemailer.createTransport({
        host: "email-smtp.us-east-1.amazonaws.com",
        port: 465,
        secure: true,
        auth: {
            user: config.EMAIL_SENDER_USER,
            pass: config.EMAIL_SENDER_PASSWORD,
        },
    })
}

// Init a nodemailer transport client configured for testing
const makeTransportTest = () => {
    // These are dummy creds the let us test emails with https://ethereal.email/
    return nodemailer.createTransport({
        host: 'smtp.ethereal.email',
        port: 587,
        auth: {
            user: 'greg.herman57@ethereal.email',
            pass: 'dbTjNNY3CEwscJ21DR'
        }
    });
}

module.exports = { initTransport };
