const config = require('../config');
const {initTransport} = require("./email/transports");
const {templates} = require("./email/templates");

const transport = initTransport();


const formatEmail = (template, data) => {
    if (!templates[template]) {
        throw new Error(`Template not available: ${template}`);
    }
    let subject = data.subject || data.title || templates[template].title || 'CB notification';
    if (data.INCIDENT_ID) {
        subject = `${subject} - ${data.INCIDENT_ID}`;
    }
    return {
        html: templates[template].renderHtml ? templates[template].renderHtml(data) : 'Invalid html',
        text: templates[template].renderText ? templates[template].renderText(data) : 'No text fallback',
        subject
    };
};

const sendEmail = ({ to, cc, html, text, subject }) => {
    return transport.sendMail({
        from: config.FROM_EMAIL,
        to,
        cc,
        subject,
        text,
        html
    })
};

module.exports = {
    sendEmail,
    formatEmail
};
