const Sequelize = require('sequelize');
const db = require('./db');

const baseFields = [
    {
        name: 'updatedat',
        exposed: true,
        type: Sequelize.DATE,
        defaultValue: Sequelize.NOW
    },
    {
        name: 'createdat',
        exposed: true,
        type: Sequelize.DATE,
        defaultValue: Sequelize.NOW
    }
];

const toSchema = (options = { fields: [] }) => {
    if (!(options.fields instanceof Array)) {
        throw new Error('toSchema expects an array of fields');
    }
    if (!options.collection) {
        throw new Error('toSchema expects a collection option');
    }
    const schema = db.define(options.collection,
        options.fields.reduce((obj, field) => (
            Object.assign(obj,
                {
                    [field.name]: Object.assign(
                        {},
                        field.description,
                        Object.keys(field)
                        .filter(key => ['type', 'defaultValue', 'values', 'unique', 'validate', 'primaryKey'].includes(key))
                        .reduce((res, key) => Object.assign(res, { [key]: field[key] }), {})
                    )
                }
            )
        ), {}),
        {
            freezeTableName: true
        }
    );
    schema.fields = options.fields;
    return schema;
};

module.exports = {
    baseFields,
    toSchema
};
